@@ -58,9 +58,7 @@ gi.require_version('Gst', '1.0')
 gi.require_version('Wnck', '3.0')
 gi.require_version('SugarExt', '1.0')
 gi.require_version('GdkX11', '3.0')
-gi.require_version('GConf', '2.0')
 
-from gi.repository import GObject
 from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import Gtk
@@ -186,8 +184,8 @@ def _check_for_window_manager(screen):
 
 def __window_manager_failed_cb(fd, condition):
     logging.error('window manager did fail, restarting')
-    GObject.source_remove(_metacity_sid)
-    GObject.timeout_add(1000, _restart_window_manager)
+    GLib.source_remove(_metacity_sid)
+    GLib.timeout_add(1000, _restart_window_manager)
     return False
 
 
@@ -197,8 +195,8 @@ def _restart_window_manager():
     _metacity_process = subprocess.Popen(
         ['metacity', '--no-force-fullscreen', '--no-composite'],
         stdout=subprocess.PIPE)
-    _metacity_sid = GObject.io_add_watch(_metacity_process.stdout, GLib.IO_HUP,
-                                         __window_manager_failed_cb)
+    _metacity_sid = GLib.io_add_watch(_metacity_process.stdout, GLib.IO_HUP,
+                                      __window_manager_failed_cb)
     return False
 
 
@@ -252,109 +250,6 @@ def cleanup_temporary_files():
         print 'temporary files cleanup failed: %s' % e
 
 
-def _migrate_journal_mimeregistry():
-    from gi.repository import GConf
-    client = GConf.Client.get_default()
-
-    # Now this isn't good
-    # keys in /desktop/sugar/journal/defaults are mime types
-    # which are of the sort text/plain
-    # so, GConf is thinking test is a directory and the key is plain
-    # while the key should be 'text/plain'
-
-    gconf_defaults_dir = '/desktop/sugar/journal/defaults'
-
-    entries = client.all_entries(gconf_defaults_dir)
-    for directory in client.all_dirs(gconf_defaults_dir):
-        entries.extend(client.all_entries(directory))
-
-    prefix = gconf_defaults_dir + '/'
-    prefix_length = len(prefix)
-
-    gconf_defaults = {}
-    for entry in entries:
-        key = entry.get_key()
-        key = key[prefix_length:]
-
-        # entry.get_value().get_string() causes sugar to crash later
-        # not on the call, but after some random time
-        # was impossible to debug (almost impossible)
-        value = entry.value.get_string()
-        gconf_defaults[key] = value
-
-    variant = GLib.Variant('a{ss}', gconf_defaults)
-
-    settings = Gio.Settings('org.sugarlabs.journal')
-    settings.set_value('mime-registry', variant)
-
-
-def _migrate_homeviews_settings():
-    from gi.repository import GConf
-    client = GConf.Client.get_default()
-
-    # Merge several keys into one... yay!
-    options = client.get('/desktop/sugar/desktop/view-icons')
-    gconf_view_icons = []
-    if options:
-        gconf_view_icons = [gval.get_string() for gval in options.get_list()]
-
-    # assume view-icons is the leading key
-    number_of_views = len(gconf_view_icons)
-
-    layouts = []
-    prefix = '/desktop/sugar/desktop/favorites_layout'
-
-    entries = client.all_entries('/desktop/sugar/desktop')
-    for entry in entries:
-        key = entry.get_key()
-        if key.startswith(prefix):
-            # entry.get_value().get_string() causes sugar to crash later
-            # not on the call, but after some random time
-            # was impossible to debug (almost impossible)
-            value = entry.value.get_string()
-            layouts.append((key, value))
-
-    layouts.sort()
-    gconf_layouts = [layout[1] for layout in layouts][:number_of_views]
-
-    while len(gconf_layouts) < number_of_views:
-        gconf_layouts.append('ring-layout')
-
-    options = client.get('/desktop/sugar/desktop/favorite-icons')
-    gconf_fav_icons = []
-    if options:
-        gconf_fav_icons = [gval.get_string() for gval in options.get_list()]
-        gconf_fav_icons = gconf_fav_icons[:number_of_views]
-
-    while len(gconf_fav_icons) < number_of_views:
-        gconf_fav_icons.append('emblem-favorite')
-
-    homeviews = []
-    for i, view_icon in enumerate(gconf_view_icons):
-        homeviews.append({'view-icon': view_icon, 'layout': gconf_layouts[i],
-                          'favorite-icon': gconf_fav_icons[i]})
-
-    variant = GLib.Variant('aa{ss}', homeviews)
-    settings = Gio.Settings('org.sugarlabs.desktop')
-    settings.set_value('homeviews', variant)
-
-
-def _migrate_gconf_to_gsettings():
-    try:
-        subprocess.call('gsettings-data-convert')
-    except subprocess.CalledProcessError:
-        logging.error('Unable to convert data.')
-
-    settings = Gio.Settings('org.sugarlabs')
-    migrated = settings.get_boolean('gsettings-migrated')
-
-    if not migrated:
-        _migrate_journal_mimeregistry()
-        _migrate_homeviews_settings()
-
-        settings.set_boolean('gsettings-migrated', True)
-
-
 def setup_timezone():
     settings = Gio.Settings('org.sugarlabs.date')
     timezone = settings.get_string('timezone')
@@ -452,8 +347,6 @@ def main():
 
     Gst.init(sys.argv)
 
-    _migrate_gconf_to_gsettings()
-
     cleanup_temporary_files()
 
     _start_window_manager()
